# ResourceURLHostInfoMap

A map of Host to the info associated with that host. The index is always lowercase. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**any string name** | [**ResourceURLHostInfo**](ResourceURLHostInfo.md) | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


